@@ -1,5 +1,5 @@
 package App::CLI;
-our $VERSION = '0.31';
+our $VERSION = '0.311';
 use strict;
 use warnings;
 
@@ -29,8 +29,10 @@ App::CLI - Dispatcher module for command line interface programs
     );
 
     use constant subcommands => qw(User Nickname type); # if you want subcommands
-                                                        # automatically dispatch to subcommands 
-                                                        # when invoke $ myapp list [user|nickname]
+                                                        # automatically dispatch to subcommands
+                                                        # when invoke $ myapp list [user|nickname|--type]
+                                                        # note 'type' lower case in first char
+                                                        # is subcommand of old genre which is deprecated
 
     sub run {
         my ($self, @args) = @_;
@@ -101,6 +103,8 @@ options.
 
 =cut
 
+
+use App::CLI::Helper;
 use Getopt::Long ();
 
 use constant alias => ();
@@ -116,45 +120,77 @@ sub prepare {
     my $class = shift;
     my $data = {};
 
-    $class->_getopt(
+    $class->get_opt(
         [qw(no_ignore_case bundling pass_through)],
-        _opt_map($data, $class->global_options)
+        opt_map($data, $class->global_options)
     );
 
-    my $cmd = shift @ARGV;
-    $cmd = $class->get_cmd($cmd, @_, %$data);
+    my $cmd = $class->get_cmd(shift @ARGV, @_, %$data);
 
     while ($cmd->cascadable) {
       $cmd = $cmd->cascading;
     }
 
-    $class->_getopt(
+
+    $class->get_opt(
         [qw(no_ignore_case bundling)],
-	_opt_map($cmd, $cmd->command_options)
+        opt_map($cmd, $cmd->command_options)
     );
 
+    $cmd = $cmd->subcommand;
+
     return $cmd;
 }
 
-sub _getopt {
+=head3 get_opt([@config], %opt_map)
+
+    give options map, process by Getopt::Long::Parser
+
+=cut
+
+sub get_opt {
     my $class = shift;
     my $config = shift;
     my $p = Getopt::Long::Parser->new;
     $p->configure(@$config);
     my $err = '';
-    local $SIG{__WARN__} = sub { my $msg = shift; $err .= "$msg" };
-    die $class->error_opt ($err)
-	unless $p->getoptions(@_);
+    local $SIG{__WARN__} = sub { 
+      my $msg = shift;
+      $err .= "$msg"
+    };
+    die $class->error_opt ($err) unless $p->getoptions(@_);
 }
 
+
+sub opt_map {
+    my ($self, %opt) = @_;
+    return map { $_ => ref($opt{$_}) ? $opt{$_} : \$self->{$opt{$_}}} keys %opt;
+}
+
+
+=head3
+
+interface of dispatcher
+
+=cut
+
 sub dispatch {
     my $class = shift;
-    my $cmd = $class->prepare(@_);
-    $cmd->subcommand;
-    $cmd->run_command(@ARGV);
+    $class->prepare(@_)->run_command(@ARGV);
 }
 
-sub _cmd_map {
+
+=head3 cmd_map($cmd)
+
+find package name of subcommand in constant %alias
+
+if it's finded, return ucfirst of the package name,
+
+otherwise, return ucfirst of $cmd itself.
+
+=cut
+
+sub cmd_map {
     my ($pkg, $cmd) = @_;
     my %alias = $pkg->alias;
     $cmd = $alias{$cmd} if exists $alias{$cmd};
@@ -167,53 +203,31 @@ sub error_cmd {
 
 sub error_opt { $_[1] }
 
-sub command_class { $_[0] }
+=head3 get_cmd($cmd, @arg)
+
+return subcommand of first level via $ARGV[0]
+
+=cut
 
 sub get_cmd {
     my ($class, $cmd, @arg) = @_;
-    die $class->error_cmd
-	unless $cmd && $cmd =~ m/^[?a-z]+$/;
-    my $pkg = join('::', $class->command_class, $class->_cmd_map ($cmd));
+    die $class->error_cmd unless $cmd && $cmd =~ m/^[?a-z]+$/;
 
+    my $pkg = join('::', $class, $class->cmd_map($cmd));
     my $file = "$pkg.pm";
     $file =~ s!::!/!g;
-    eval {require $file; };
+    eval { require $file; };
 
     unless ($pkg->can('run')) {
-        warn $@ if $@ and exists $INC{$file};
-        die $class->error_cmd;
+      warn $@ if $@ and exists $INC{$file};
+      die $class->error_cmd;
+    } else {
+      $cmd = $pkg->new(@arg);
+      $cmd->app($class);
+      return $cmd;
     }
-
-    $cmd = $pkg->new (@arg);
-    $cmd->app ($class);
-
-    return $cmd;
 }
 
-sub _opt_map {
-    my ($self, %opt) = @_;
-    return map { $_ => ref($opt{$_}) ? $opt{$_} : \$self->{$opt{$_}}} keys %opt;
-}
-
-sub commands {
-    my $class = shift;
-    $class =~ s{::}{/}g;
-    my $dir = $INC{$class.'.pm'};
-    $dir =~ s/\.pm$//;
-    return sort map { ($_) = m{^\Q$dir\E/(.*)\.pm}; lc($_) } $class->files;
-}
-
-sub files {
-    my $class = shift;
-    $class =~ s{::}{/}g;
-    my $dir = $INC{$class.'.pm'};
-    $dir =~ s/\.pm$//;
-    return sort glob("$dir/*.pm");
-}
-
-=head1 TODO
-
-More documentation
 
 =head1 SEE ALSO
 
